@@ -261,7 +261,8 @@ impl TerserCompressorOptions {
             comparisons: self.comparisons.unwrap_or(self.defaults),
             // TODO: Use self.defaults
             computed_props: self.computed_props.unwrap_or(false),
-            conditionals: self.conditionals.unwrap_or(self.defaults),
+            // TODO: Use self.defaults
+            conditionals: self.conditionals.unwrap_or(false),
             dead_code: self.dead_code.unwrap_or(self.defaults),
             // TODO: Use self.defaults
             directives: self.directives.unwrap_or(false),
